'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _minimist = require('minimist');

var _minimist2 = _interopRequireDefault(_minimist);

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _progress = require('progress');

var _progress2 = _interopRequireDefault(_progress);

var _quizGenerator = require('../quiz-generator.js');

var _quizGenerator2 = _interopRequireDefault(_quizGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; } /* eslint-disable no-console */


const showUsage = () => {
  console.log(`word-quiz-generator coverage --help
word-quiz-generator coverage --material=<path> --sources=<paths> [--show-uncovered]
                             [--sentenceSeparator=<RegExp>] [--clauseRegExp=<RegExp>]
                             [--wordRegExp=<RegExp>] [--wordBoundaryRegExp=<RegExp>]
                             [--abbrRegExp=<RegExp>]

Measure the coverage of words/phrases in the given material against the given sources.

-h, --help
    Show this usage.
-m, --material=<path>
    Path to a material.
-s, --sources=<paths>
    Comma-separated path strings to sources.
-u, --show-uncovered
    Show uncovered words/phrases.

The following options determines how to extract a word/phrase or sentence from a text.
For English sources, these are automatically set and usually don't need to override them.

--sentenceSeparator=<RegExp>
    Regular expression representing a sentence separator. Default: '(?:[?!.]\\s?)+"?(?:\\s|$)(?!,)'
--clauseRegExp=<RegExp>
    Regular expression representing a clause. Default: '[^,:"?!.]+'
--wordRegExp=<RegExp>
    Regular expression representing a word. Default: '[\\w'-]+'
--wordBoundaryRegExp=<RegExp>
    Regular expression representing a word boundary. Default: '\\b'
--abbrRegExp=<RegExp>
    Regular expression representing an abbreviation mark. Default: '\\.\\.\\.'`);
};

exports.default = function () {
  var ref = _asyncToGenerator(function* (args) {
    const argv = (0, _minimist2.default)(args, {
      string: ['material', 'sources', 'sentenceSeparator', 'clauseRegExp', 'wordRegExp', 'wordBoundaryRegExp', 'abbrRegExp'],
      boolean: ['show-uncovered', 'help'],
      alias: {
        m: 'material',
        s: 'sources',
        u: 'show-uncovered',
        h: 'help'
      }
    });

    if (argv.help) {
      showUsage();
      process.exit(0);
    }

    if (!argv.material || !argv.sources) {
      showUsage();
      process.exit(1);
    }

    const material = argv.material;
    const sources = argv.sources;
    const sentenceSeparator = argv.sentenceSeparator && new RegExp(argv.sentenceSeparator, 'g');
    const clauseRegExp = argv.clauseRegExp && new RegExp(argv.clauseRegExp, 'g');
    const wordRegExp = argv.wordRegExp && new RegExp(argv.wordRegExp, 'g');
    const wordBoundaryRegExp = argv.wordBoundaryRegExp && new RegExp(argv.wordBoundaryRegExp);
    const abbrRegExp = argv.abbrRegExp && new RegExp(argv.abbrRegExp, 'g');
    const generator = new _quizGenerator2.default({
      material, sources, sentenceSeparator, clauseRegExp, wordRegExp,
      wordBoundaryRegExp, abbrRegExp
    });

    yield generator.init();

    const phrases = generator._phrases;
    const total = phrases.length;
    const uncovered = [];
    const progress = new _progress2.default('[:bar] :percent :etas', {
      complete: '=',
      incomplete: ' ',
      width: 20,
      total: phrases.length
    });

    while (phrases.length) {
      const phrase = phrases.shift();
      const question = yield generator.question(phrase);

      if (!question) {
        uncovered.push(phrase);
      }

      progress.tick();
    }

    const coverage = (total - uncovered.length) * 100 / total;

    console.log(_colors2.default.bold(`Coverage: ${ coverage.toFixed(2) }%`));

    if (argv['show-uncovered']) {
      console.log(_colors2.default.bold('Uncovered Phrases'));
      console.log(uncovered);
    }
  });

  return function (_x) {
    return ref.apply(this, arguments);
  };
}();
//# sourceMappingURL=coverage.js.map