'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _minimist = require('minimist');

var _minimist2 = _interopRequireDefault(_minimist);

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _quizGenerator = require('../quiz-generator.js');

var _quizGenerator2 = _interopRequireDefault(_quizGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; } /* eslint-disable no-console */


const showUsage = () => {
  console.log(`word-quiz-generator generate --help
word-quiz-generator generate --material=<path> --sources=<paths> --sections --size
                             [--instruction] [--sentenceSeparator=<RegExp>]
                             [--clauseRegExp=<RegExp>] [--wordRegExp=<RegExp>]
                             [--wordBoundaryRegExp=<RegExp>] [--abbrRegExp=<RegExp>]

Generate a quiz and put it to stdout using the given material and sources.

-h, --help
    Show this usage.
-m, --material=<path>
    Path to a material.
-s, --sources=<paths>
    Comma-separated path strings to sources.
-e, --sections=<sections>
    Quiz coverage. e.g. '1-10', '5', '3-'
-i, --size=<num>
    The number of questions.
--instruction
    The instruction text located at top of the quiz.
    Default: 'Write down the meaning of underlined words/phrases.'
--skip-spaces
    Specify if a language you want to make a quiz has no word divider, such as Japanese and Chinese.

The following options determines how to extract a word/phrase or sentence from a text.
For English quiz, these are automatically set and usually don't need to override them.

--sentenceSeparator=<RegExp>
    Regular expression representing a sentence separator. Default: '(?:[?!.]\\s?)+"?(?:\\s|$)(?!,)'
--clauseRegExp=<RegExp>
    Regular expression representing a clause. Default: '[^,:"?!.]+'
--wordRegExp=<RegExp>
    Regular expression representing a word. Default: '[\\w'-]+'
--wordBoundaryRegExp=<RegExp>
    Regular expression representing a word boundary. Default: '\\b'
--abbrRegExp=<RegExp>
    Regular expression representing an abbreviation mark. Default: '\\.\\.\\.'`);
};

exports.default = function () {
  var ref = _asyncToGenerator(function* (args) {
    const argv = (0, _minimist2.default)(args, {
      string: ['material', 'sources', 'sections', 'size', 'instruction', 'sentenceSeparator', 'clauseRegExp', 'wordRegExp', 'wordBoundaryRegExp', 'abbrRegExp'],
      boolean: ['skip-spaces', 'help'],
      alias: {
        m: 'material',
        s: 'sources',
        e: 'sections',
        i: 'size'
      },
      default: {
        instruction: 'Write down the meaning of underlined words/phrases.',
        wordRegExp: '[\\w\'-]+' }
    });

    // need for display
    if (argv.help) {
      showUsage();
      process.exit(0);
    }

    if (!argv.material || !argv.sources || !argv.sections || !argv.size) {
      showUsage();
      process.exit(1);
    }

    const material = argv.material;
    const sources = argv.sources;
    const sentenceSeparator = argv.sentenceSeparator && new RegExp(argv.sentenceSeparator, 'g');
    const clauseRegExp = argv.clauseRegExp && new RegExp(argv.clauseRegExp, 'g');
    const wordRegExp = argv.wordRegExp && new RegExp(argv.wordRegExp, 'g');
    const wordBoundaryRegExp = argv.wordBoundaryRegExp && new RegExp(argv.wordBoundaryRegExp);
    const abbrRegExp = argv.abbrRegExp && new RegExp(argv.abbrRegExp, 'g');
    const generator = new _quizGenerator2.default({
      material, sources, sentenceSeparator, clauseRegExp, wordRegExp,
      wordBoundaryRegExp, abbrRegExp
    });
    yield generator.init();

    const sections = argv.sections;
    const size = Number(argv.size);
    const questions = yield generator.quiz({ sections, size });

    console.log(_colors2.default.bold(argv.instruction));
    questions.forEach(function (question, i) {
      const sentenceParts = [];
      const blockRegExp = new RegExp(`(${ argv.wordRegExp })(\\s+)?`, 'g');
      const sentence = question.sentence;
      const wordIndexes = question.wordIndexes;

      const divider = argv['skip-spaces'] ? '' : ' ';
      let currentWordIndex = 0;
      let prevLastIndex = 0;
      let matched;

      // Set underlines at target expressions.
      // eslint-disable-next-line no-cond-assign
      while (matched = blockRegExp.exec(sentence)) {
        var _matched = matched;

        var _matched2 = _slicedToArray(_matched, 3);

        const word = _matched2[1];
        const hasDivider = _matched2[2];

        const divider_ = !!hasDivider ? divider : '';
        const punctuation = sentence.substring(prevLastIndex, matched.index);

        if (wordIndexes[0] === currentWordIndex) {
          const isSuccessive = wordIndexes[0] + 1 === wordIndexes[1];

          if (isSuccessive) {
            sentenceParts.push(`${ punctuation }${ _colors2.default.underline(`${ word }${ divider_ }`) }`);
          } else {
            sentenceParts.push(`${ punctuation }${ _colors2.default.underline(word) }${ divider_ }`);
          }

          wordIndexes.shift();
        } else {
          sentenceParts.push(`${ punctuation }${ word }${ divider_ }`);
        }

        currentWordIndex++;
        prevLastIndex = blockRegExp.lastIndex;
      }

      const stopPunctuation = sentence.substring(prevLastIndex);
      sentenceParts.push(stopPunctuation);

      console.log(`(${ i + 1 })\t${ sentenceParts.join('') }\t(${ question.reference })`);
    });

    console.log(_colors2.default.bold('\nAnswer Keys'));
    questions.forEach(function (q, i) {
      console.log(`(${ i + 1 })\t${ q.answer }`);
    });
  });

  return function (_x) {
    return ref.apply(this, arguments);
  };
}();
//# sourceMappingURL=generate.js.map